@@ -485,6 +485,14 @@ class T31A(T30A):
 
         return consumptions
 
+    def apply_curve_losses(self, measures):
+        for idx, measure in enumerate(measures):
+            values = measure._asdict()
+            consumption = round(measure.measure * (1 + self.losses), 2) + round(0.01 * self.kva, 2)
+            values['measure'] = consumption
+            measures[idx] = measure._replace(**values)
+        return measures
+
     def evaluate_powers(self, powers):
         super(T31A, self).evaluate_powers(powers)
 
